# Acknowledgements

Most of the theoretical and technical work that is shown as algebraic
expressions occurred in the Mathematica coding enviroment. Porting the
code to Python has been a learning experience. It was not immediately
obvious to me that the Python language would be able to support the math
required to understand algebraic evaluation - but it does! As they say,
"Batteries included". So I wanted to acknowledge some of the software that
I am using and links to videos or tutorials from the Python community that
have helped me prepare this initial release.

1. Theoretically, [SymPy](https://www.sympy.org/en/index.html) is the most
   important tool. It provides the algorithms from algebraic geometry that
   are central to turning the generating set of polynomials for the
   test data sketches into the tiered postulates that allow one to calculate
   all the error correlations **given** their individual performance.

2. As a research scientist in industry, most of my software is for personal
   and/or team use at most. Software engineering is an art by itself. Some
   links that have helped me try to practice it -
     * []